<template>
  <el-dialog
    width="60%"
    title="班次记录"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="duty-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      ref="dutyRecordTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
    <!-- 弹窗, 新增 / 修改 -->
    <table-form
      v-if="addOrUpdateVisible"
      ref="addOrUpdate"
      :workstationId="workstationId"
      @refreshDataList="getData"
    ></table-form>
    <!-- 弹窗, 操作记录 -->
    <operatingRecordTable
      :currshowlist.sync="operatingRecordVisible"
      ref="operatingRecord"
      :currentDutyRecord="currentRow"
    ></operatingRecordTable>
  </el-dialog>
</template>
<script>
import {
  fetchListDutyRecord,
  delDutyRecord,
  putDutyRecord
} from '@/api/product/dutyrecord'
import { getAllWorkstationList } from '@/api/basic/workstation'
import ttable from '@/views/common/ztt-table'
import TableForm from './dutyrecord-tabform'
import operatingRecordTable from './operatingrecordtable'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    workstationId: {
      type: Number,
      default: null
    }
  },
  data() {
    return {
      ajaxFun: fetchListDutyRecord,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'dutyDate', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            width: '140',
            prop: 'dutyNo',
            label: '班次编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          {
            width: '60',
            prop: 'isSubmit',
            label: '提交',
            sort: false,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatIsSubmit,
            optList: () => {
              return this.booleanOptions
            }
          },
          {
            width: '60',
            prop: 'isConfirm',
            label: '确认',
            sort: false,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue) {
                formatVal = '<span>是</span>'
              } else {
                formatVal = '<span style="color:red">否</span>'
              }
              return formatVal
            },
            optList: () => {
              return this.booleanOptions
            }
          },
          {
            width: '100',
            prop: 'dutyDate',
            label: '班次日期',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          },
          {
            width: '80',
            prop: 'shiftName',
            label: '生产班次',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            prop: 'workstationName',
            label: '工作站',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '80',
            prop: 'dutyTime',
            label: '班次时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '80',
            prop: 'crewName',
            label: '生产班组',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            prop: 'dutyOutput',
            label: '班次产量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            prop: 'receiveRemark',
            label: '接班记录',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            prop: 'deliveryRemark',
            label: '交班记录',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            prop: 'startTime',
            label: '开始',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          {
            width: '140',
            prop: 'endTime',
            label: '结束',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          {
            width: '80',
            prop: 'createUser',
            label: '创建人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '操作记录',
            type: 'primary',
            fun: this.operatingRecord
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      booleanOptions: [
        { value: true, label: '是' },
        { value: false, label: '否' }
      ],
      operatingRecordVisible: false
    }
  },
  components: {
    ttable,
    TableForm,
    operatingRecordTable
  },
  methods: {
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit('handleSelectionChange', this.multipleSelection)
      } else {
        this.$emit('listenToDutyEvent', this.currentRow)
      }
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      if (this.$refs.dutyRecordTable !== undefined) {
        this.$refs.dutyRecordTable.getDataList()
      }
    },
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 格式化日期
    formatDutyDate(row, column, cellValue) {
      if (cellValue) {
        const dutyDateList = /\d{4}-\d{1,2}-\d{1,2}/g.exec(cellValue)
        if (dutyDateList && dutyDateList.length > 0) {
          return dutyDateList[0]
        }
      }
      return ''
    },
    // 提交列中文格式化
    formatIsSubmit(row, column, cellValue) {
      if (cellValue) {
        return '是'
      } else {
        return '否'
      }
    },
    // 打开操作记录页面
    operatingRecord() {
      if (this.currentRow) {
        this.operatingRecordVisible = true
      } else {
        this.$message.warning('请先选择上班记录')
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    },
    workstationId: {
      handler: function(newVal, oldVal) {
        this.$nextTick(() => {
          getAllWorkstationList().then((response) => {
            const workstations = response.data.data
            if (this.workstationId && workstations && workstations.length > 0) {
              const workstation = workstations.find(
                (workstation) => workstation.id === this.workstationId
              )
              if (workstation && workstation.name) {
                const workstationNameColumn = this.table.column.find(
                  (column) => column.prop === 'workstationName'
                )
                if (workstationNameColumn) {
                  this.$set(workstationNameColumn, 'propVal', workstation.name)
                  if (this.$refs.dutyRecordTable) {
                    this.$refs.dutyRecordTable.initSearchCondition()
                  }
                }
              }
            }
          })
        })
      },
      immediate: true
    }
  }
}
</script>
<style>
.duty-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}

.duty-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}

.duty-dialog .el-dialog__body {
  padding: 5px 20px;
}

.duty-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.duty-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
